import { Injectable, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';

import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';

import { _MODULE_CONFIG } from '../types/token';
import {
  VersionInfoRequest,
  VersionInfoResponse
} from '../models/version-info';
import { UpdateInfoRequest, UpdateInfoResponse } from '../models/update-info';
import { ModuleConfig } from '../types/module-config';

@Injectable({
  providedIn: 'root'
})
export class PublicApiService {
  constructor(
    @Inject(_MODULE_CONFIG) private moduleConfig: ModuleConfig,
    private httpClient: HttpClient
  ) {}

  public versionInfo(req: VersionInfoRequest): Observable<VersionInfoResponse> {
    return this.httpClient
      .post<any>(
        this.moduleConfig.urls.versionInfo,
        {},
        {
          params: {
            p_user_seq: req.userSeq,
            p_device_type: req.deviceType,
            p_token: req.token,
            p_comp_group_type: req.companyGroupType,
            p_comp_code: req.companyCode,
            p_login_id: req.loginId
          }
        }
      )
      .pipe(
        map(res => {
          return {
            statusCode: res.StatusCode,
            errorMessage: res.ErrorMessage,
            protocolCode: res.ProtocolCD,
            syncMode: res.SyncMode,
            appVersion: res.AppVer,
            installUrl: res.InstallURL,
            serverIp: res.ServerIP,
            serverPort: res.ServerPort,
            uploadUrl: res.UploadURL,
            downloadUrl: res.DownloadURL,
            profileUploadUrl: res.ProfileUploadURL,
            profileRoot: res.ProfileRoot,
            fileTerm: res.FileTerm,
            fileAllowSize: res.FileAllowSize,
            authIp: res.AuthIP,
            launcherAppVersion: res.LauncherAppVer,
            launcherInstallUrl: res.LauncherInstallURL
          } as VersionInfoResponse;
        })
      );
  }

  public updateInfo(req: UpdateInfoRequest): Observable<UpdateInfoResponse> {
    return this.httpClient
      .post<any>(
        this.moduleConfig.urls.updateInfo,
        {},
        {
          params: {
            p_device_type: req.deviceType
          }
        }
      )
      .pipe(
        map(res => {
          return {
            statusCode: res.StatusCode,
            errorMessage: res.ErrorMessage,
            appVersion: res.AppVer,
            installUrl: res.InstallURL,
            launcherAppVersion: res.LauncherAppVer,
            launcherInstallUrl: res.LauncherInstallURL
          } as UpdateInfoResponse;
        })
      );
  }
}
